@@ -1,10 +1,10 @@
-__version__ = 1.0
-__copyright__ = 'Copyright (c) 2009-2013, Kyle Fuller'
+__version__ = '1.0.1'
+__copyright__ = 'Copyright (c) 2009-2014, Kyle Fuller'
 __licence__ = 'BSD'
 __author__ = [
     'Kyle Fuller <inbox@kylefuller.co.uk>',
     'Jannis Leidel (jezdez)',
     'krisje8 <krisje8@gmail.com>',
 ]
-__URL__ = 'http://kylefuller.co.uk/project/django-request/'
+__URL__ = 'http://django-request.readthedocs.org/en/latest/'
 
